@@ -5,9 +5,9 @@ from jsonfield import JSONField
 
 
 class KeyValue(models.Model):
-    group = models.ForeignKey(Group)
+    group = models.ForeignKey(Group, on_delete=models.CASCADE)
     key = models.CharField(max_length=64, db_index=True)
     value = JSONField()
 
-    def __unicode__(self):
-        return u'KV(%s, %s, %r)' % (self.group.name, self.key, self.value)
+    def __str__(self):
+        return 'KV(%s, %s, %r)' % (self.group.name, self.key, self.value)
