@@ -5,15 +5,15 @@ from wafer.pages.models import File, Page
 from wafer.compare.admin import CompareVersionAdmin, DateModifiedFilter
 
 
-class PageAdmin(CompareVersionAdmin, admin.ModelAdmin):
+class PageAdmin(CompareVersionAdmin):
     prepopulated_fields = {"slug": ("name",)}
     list_display = ('name', 'slug', 'get_absolute_url',
+                    'include_in_menu', 'menu_order',
                     'cache_time', 'get_people_display_names',
                     'get_in_schedule')
 
     list_filter = (DateModifiedFilter,)
 
 
-
 admin.site.register(Page, PageAdmin)
 admin.site.register(File)
