@@ -4,7 +4,7 @@ from rest_framework import routers
 
 from wafer.schedule.views import (
     CurrentView, ScheduleView, ScheduleItemViewSet, ScheduleXmlView,
-    VenueView, ICalView)
+    VenueView, ICalView, JsonDataView)
 
 router = routers.DefaultRouter()
 router.register(r'scheduleitems', ScheduleItemViewSet)
@@ -16,5 +16,6 @@ urlpatterns = [
     url(r'^pentabarf\.xml$', ScheduleXmlView.as_view(),
         name='wafer_pentabarf_xml'),
     url(r'^schedule\.ics$', ICalView.as_view(), name="schedule.ics"),
+    url(r'^schedule\.json$', JsonDataView.as_view(), name="schedule.json"),
     url(r'^api/', include(router.urls)),
 ]
