@@ -17,10 +17,13 @@ DATABASES = {
 }
 
 if os.environ.get('TESTDB', None) == 'postgres':
+    # settings for running the tests
     DATABASES['default'].update({
         'ENGINE': 'django.db.backends.postgresql_psycopg2',
         'USER': 'postgres',
+        'PASSWORD': 'postgres',
         'NAME': 'wafer',
+        'HOST': 'localhost',
         })
 
 # Hosts/domain names that are valid for this site; required if DEBUG is False
@@ -196,8 +199,8 @@ LOGGING = {
 
 # Django registration:
 ACCOUNT_ACTIVATION_DAYS = 7
-
 AUTH_USER_MODEL = 'auth.User'
+REGISTRATION_FORM = 'wafer.registration.forms.WaferRegistrationForm'
 
 # Forms:
 CRISPY_TEMPLATE_PACK = 'bootstrap4'
@@ -264,6 +267,9 @@ WAFER_TALKS_OPEN = True
 # The form used for talk submission
 WAFER_TALK_FORM = 'wafer.talks.forms.TalkForm'
 
+# Languages the talks can be in
+WAFER_TALK_LANGUAGES = ()
+
 # Ask speakers for video release, and an email address of a reviewer
 WAFER_VIDEO = True
 WAFER_VIDEO_REVIEWER = True
