@@ -86,6 +86,12 @@ class TalkType(models.Model):
         help_text=_("Whether submissions after the deadline should be accepted")
     )
 
+    show_speakers = models.BooleanField(
+        _('Show authors in speakers list'),
+        default=True,
+        help_text=_("Whether to show the authors for this talk type in the speakers list")
+    )
+
     objects = TalkTypeManager()
 
     def __str__(self):
@@ -157,6 +163,17 @@ class Talk(models.Model):
     track = models.ForeignKey(
         Track, verbose_name=_("track"), null=True, blank=True, on_delete=models.SET_NULL)
 
+    LANGUAGES = settings.WAFER_TALK_LANGUAGES
+    DEFAULT_LANGUAGE = LANGUAGES and LANGUAGES[0][0]
+    language = models.CharField(
+        verbose_name=_("language"),
+        max_length=5,
+        null=True,
+        blank=True,
+        choices=LANGUAGES,
+        default=DEFAULT_LANGUAGE,
+    )
+
     title = models.CharField(_("title"), max_length=1024)
 
     abstract = MarkupField(
@@ -375,8 +392,10 @@ class Review(models.Model):
         help_text=_("Comments on the proposal (markdown)"))
 
     def __str__(self):
-        return _(u'Review of %s by %s (%s)') % (
-            self.talk.title, self.reviewer, self.avg_score)
+        return _(u'Review of %(title)s by %(reviewer)s (%(average_score)s)') % {
+                'title': self.talk.title,
+                'reviewer': self.reviewer,
+                'average_score': self.avg_score}
 
     @property
     def avg_score(self):
@@ -420,8 +439,11 @@ class Score(models.Model):
 
     def __str__(self):
         review = self.review
-        return _(u'Review of %s by %s on %s: %i') % (
-            review.reviewer, review.talk.title, self.aspect.name, self.value)
+        return _(u'Review of %(title)s by %(reviewer)s on %(aspect)s: %(score)i') % {
+                'title': review.talk.title,
+                'reviewer': review.reviewer,
+                'aspect': self.aspect.name,
+                'score': self.value}
 
     class Meta:
         unique_together = (('review', 'aspect'),)
