@@ -12,7 +12,7 @@ from bakery.views import BuildableDetailView
 from rest_framework import viewsets
 from rest_framework.permissions import IsAdminUser
 
-from wafer.talks.models import ACCEPTED
+from wafer.talks.models import ACCEPTED, CANCELLED
 from wafer.users.forms import UserForm, UserProfileForm
 from wafer.users.serializers import UserSerializer
 from wafer.users.models import UserProfile
@@ -30,7 +30,7 @@ class UsersView(PaginatedBuildableListView):
     def get_queryset(self, *args, **kwargs):
         qs = super(UsersView, self).get_queryset(*args, **kwargs)
         if not settings.WAFER_PUBLIC_ATTENDEE_LIST:
-            qs = qs.filter(talks__status=ACCEPTED).distinct()
+            qs = qs.filter(talks__status__in=(ACCEPTED, CANCELLED)).distinct()
         qs = qs.order_by('first_name', 'last_name', 'username')
         return qs
 
@@ -66,14 +66,17 @@ class ProfileView(Hide404Mixin, BuildableDetailView):
         return reverse('wafer_user_profile', args=(obj.username,))
 
     def build_object(self, obj):
-        """Override django-bakery to skip profiles that raise 404"""
+        """Override django-bakery to skip profiles that raise 403"""
+        if obj.username in ('.', '..'):
+            log.warning('Skipping build of user %s, bad username', obj.username)
+            return
         try:
             build_path = self.get_build_path(obj)
             self.request = self.create_request(build_path)
             self.request.user = AnonymousUser()
             self.set_kwargs(obj)
             self.build_file(build_path, self.get_content())
-        except Http404:
+        except PermissionDenied:
             # cleanup directory
             self.unbuild_object(obj)
 
@@ -81,7 +84,7 @@ class ProfileView(Hide404Mixin, BuildableDetailView):
         object_ = super(ProfileView, self).get_object(*args, **kwargs)
         if not settings.WAFER_PUBLIC_ATTENDEE_LIST:
             if (not self.can_edit(object_) and
-                    not object_.userprofile.accepted_talks().exists()):
+                    not object_.userprofile.published_talks().exists()):
                 raise PermissionDenied()
         return object_
 
